Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1586)

Unified Diff: chrome/browser/app_modal_dialog_queue.h

Issue 63033: Refactor AppModalDialogQueue and move JS Alert boxes into a MVC. (Closed)
Patch Set: whitespace Created 11 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/app_modal_dialog.cc ('k') | chrome/browser/app_modal_dialog_queue.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/app_modal_dialog_queue.h
diff --git a/chrome/browser/app_modal_dialog_queue.h b/chrome/browser/app_modal_dialog_queue.h
index 2482d5a97b8f31a946da291f700123d7efccebe0..bfe755cb02baff0ef90b2240f9915d25f0e4fde7 100644
--- a/chrome/browser/app_modal_dialog_queue.h
+++ b/chrome/browser/app_modal_dialog_queue.h
@@ -7,9 +7,9 @@
#include <queue>
-#include "chrome/views/window/app_modal_dialog_delegate.h"
+#include "chrome/browser/app_modal_dialog.h"
-// Keeps a queue of AppModalDialogDelegates, making sure only one app modal
+// Keeps a queue of AppModalDialogs, making sure only one app modal
// dialog is shown at a time.
class AppModalDialogQueue {
public:
@@ -21,9 +21,9 @@ class AppModalDialogQueue {
// assure it is the child of BrowserList::GetLastActive() so that it is
// activated as well. See browser_list.h for more notes about our somewhat
// sloppy app modality.
// Note: The AppModalDialogDelegate |dialog| must be window modal before it
// can be added as app modal.
- static void AddDialog(views::AppModalDialogDelegate* dialog);
+ static void AddDialog(AppModalDialog* dialog);
// Removes the current dialog in the queue (the one that is being shown).
// Shows the next dialog in the queue, if any is present. This does not
@@ -45,22 +45,21 @@ class AppModalDialogQueue {
}
// Accessor for |active_dialog_|.
- static views::AppModalDialogDelegate* active_dialog() {
+ static AppModalDialog* active_dialog() {
return active_dialog_;
}
private:
// Shows |dialog| and notifies the BrowserList that a modal dialog is showing.
- static void ShowModalDialog(views::AppModalDialogDelegate* dialog);
+ static void ShowModalDialog(AppModalDialog* dialog);
// Contains all app modal dialogs which are waiting to be shown, with the
// currently modal dialog at the front of the queue.
- static std::queue<views::AppModalDialogDelegate*>*
- app_modal_dialog_queue_;
+ static std::queue<AppModalDialog*>* app_modal_dialog_queue_;
// The currently active app-modal dialog box's delegate. NULL if there is no
// active app-modal dialog box.
- static views::AppModalDialogDelegate* active_dialog_;
+ static AppModalDialog* active_dialog_;
};
#endif // CHROME_BROWSER_APP_MODAL_DIALOG_QUEUE_H__
« no previous file with comments | « chrome/browser/app_modal_dialog.cc ('k') | chrome/browser/app_modal_dialog_queue.cc » ('j') | no next file with comments »
@@ -21,9 +21,9 @@ class AppModalDialogQueue {
// activated as well. See browser_list.h for more notes about our somewhat
// sloppy app modality.
- // Note: The AppModalDialogDelegate |dialog| must be window modal before it
+ // Note: The AppModalDialog |dialog| must be window modal before it
// can be added as app modal.

Powered by Google App Engine
This is Rietveld 408576698